==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/plugin/lang/ja/lang.php <==
<?php
/**
 * japanese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Yuji Takenaka <webmaster@davilin.com>
 * @author Christopher Smith <chris@jalakai.co.uk>
 * @author Ikuo Obataya <i.obataya@gmail.com>
 * @author Daniel Dupriest <kououken@gmail.com>
 * @author Kazutaka Miyasaka <kazmiya@gmail.com>
 */
$lang['menu']                  = 'プラグイン管理';
$lang['download']              = 'プラグインのダウンロードとインストール';
$lang['manage']                = 'インストール済みプラグイン';
$lang['btn_info']              = '情報';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '削除';
$lang['btn_settings']          = '設定';
$lang['btn_download']          = 'ダウンロード';
$lang['btn_enable']            = '保存';
$lang['url']                   = 'URL';
$lang['installed']             = 'インストール：';
$lang['lastupdate']            = '最終更新日：';
$lang['source']                = 'ソース：';
$lang['unknown']               = '不明';
$lang['updating']              = '更新中...';
$lang['updated']               = 'プラグイン %s は更新されました';
$lang['updates']               = '次のプラグインが更新されました：';
$lang['update_none']           = 'プラグインの更新データはありません。';
$lang['deleting']              = '削除中...';
$lang['deleted']               = 'プラグイン %s は削除されました。';
$lang['downloading']           = 'ダウンロード中...';
$lang['downloaded']            = 'プラグイン %s がインストールされました';
$lang['downloads']             = '次のプラグインがインストールされました：';
$lang['download_none']         = 'プラグインが見つかりませんでした。もしくはダウンロードかインストールの最中に予期せぬエラーが発生しました。';
$lang['plugin']                = 'プラグイン：';
$lang['components']            = 'コンポーネント';
$lang['noinfo']                = 'このプラグインに関する情報がありません。有効なプラグインではないかも知れません。';
$lang['name']                  = '名前：';
$lang['date']                  = '日付：';
$lang['type']                  = 'タイプ：';
$lang['desc']                  = '説明：';
$lang['author']                = '作者：';
$lang['www']                   = 'ウェブサイト：';
$lang['error']                 = '予期せぬエラーが発生しました。';
$lang['error_download']        = 'プラグインファイルをダウンロードできません：%s';
$lang['error_badurl']          = 'URLが正しくないようです - ファイル名が特定できません';
$lang['error_dircreate']       = 'ダウンロードしたファイルを一時的に保管しておくフォルダが作成できません';
$lang['error_decompress']      = 'ダウンロードしたファイルを解凍できませんでした。ダウンロードに失敗した可能性があります（もう一度、実行してください）；もしくは、不明な圧縮形式であるかもしれません（手動でインストールする必要があります）';
$lang['error_copy']            = 'プラグインをインストール中にファイルのコピーに失敗しました。<em>%s</em>：ディスク容量や書き込みの権限を確認してください。このエラーによりプラグインのインストールが完全に行われず、Wikiが不安定な状態です。';
$lang['error_delete']          = 'プラグインの削除中にエラーが発生しました <em>%s</em>。プラグインが不完全なファイルであったか、ディレクトリの権限が正しくないことが原因であると考えられます。';
$lang['enabled']               = 'プラグイン %s が有効です。';
$lang['notenabled']            = 'プラグイン %s を有効にすることができません。権限を確認してください。';
$lang['disabled']              = 'プラグイン %s が無効です。';
$lang['notdisabled']           = 'プラグイン %s を無効にすることができません。権限を確認してください。';
$lang['packageinstalled']      = 'プラグインパッケージ（%d plugin%s: %s）は正しくインストールされました。';

==> dokuwiki-2012.01.25b.tgz: dokuwiki/lib/plugins/plugin/lang/ja/lang.php <==
<?php
/**
 * japanese language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Yuji Takenaka <webmaster@davilin.com>
 * @author Christopher Smith <chris@jalakai.co.uk>
 * @author Ikuo Obataya <i.obataya@gmail.com>
 * @author Daniel Dupriest <kououken@gmail.com>
 * @author Kazutaka Miyasaka <kazmiya@gmail.com>
 */
$lang['menu']                  = 'プラグイン管理';
$lang['download']              = 'プラグインのダウンロードとインストール';
$lang['manage']                = 'インストール済みプラグイン';
$lang['btn_info']              = '情報';
$lang['btn_update']            = '更新';
$lang['btn_delete']            = '削除';
$lang['btn_settings']          = '設定';
$lang['btn_download']          = 'ダウンロード';
$lang['btn_enable']            = '保存';
$lang['url']                   = 'URL';
$lang['installed']             = 'インストール：';
$lang['lastupdate']            = '最終更新日：';
$lang['source']                = 'ソース：';
$lang['unknown']               = '不明';
$lang['updating']              = '更新中...';
$lang['updated']               = 'プラグイン %s は更新されました';
$lang['updates']               = '次のプラグインが更新されました：';
$lang['update_none']           = 'プラグインの更新データはありません。';
$lang['deleting']              = '削除中...';
$lang['deleted']               = 'プラグイン %s は削除されました。';
$lang['downloading']           = 'ダウンロード中...';
$lang['downloaded']            = 'プラグイン %s がインストールされました';
$lang['downloads']             = '次のプラグインがインストールされました：';
$lang['download_none']         = 'プラグインが見つかりませんでした。もしくはダウンロードかインストールの最中に予期せぬエラーが発生しました。';
$lang['plugin']                = 'プラグイン：';
$lang['components']            = 'コンポーネント';
$lang['noinfo']                = 'このプラグインに関する情報がありません。有効なプラグインではないかも知れません。';
$lang['name']                  = '名前：';
$lang['date']                  = '日付：';
$lang['type']                  = 'タイプ：';
$lang['desc']                  = '説明：';
$lang['author']                = '作者：';
$lang['www']                   = 'ウェブサイト：';
$lang['error']                 = '予期せぬエラーが発生しました。';
$lang['error_download']        = 'プラグインファイルをダウンロードできません：%s';
$lang['error_badurl']          = 'URLが正しくないようです - ファイル名が特定できません';
$lang['error_dircreate']       = 'ダウンロードしたファイルを一時的に保管しておくフォルダが作成できません';
$lang['error_decompress']      = 'ダウンロードしたファイルを解凍できませんでした。ダウンロードに失敗した可能性があります（もう一度、実行してください）；もしくは、不明な圧縮形式であるかもしれません（手動でインストールする必要があります）';
$lang['error_copy']            = 'プラグインをインストール中にファイルのコピーに失敗しました。<em>%s</em>：ディスク容量や書き込みの権限を確認してください。このエラーによりプラグインのインストールが完全に行われず、Wikiが不安定な状態です。';
$lang['error_delete']          = 'プラグインの削除中にエラーが発生しました <em>%s</em>。プラグインが不完全なファイルであったか、ディレクトリの権限が正しくないことが原因であると考えられます。';
$lang['enabled']               = 'プラグイン %s が有効です。';
$lang['notenabled']            = 'プラグイン %s を有効にすることができません。権限を確認してください。';
$lang['disabled']              = 'プラグイン %s が無効です。';
$lang['notdisabled']           = 'プラグイン %s を無効にすることができません。権限を確認してください。';
$lang['packageinstalled']      = 'プラグインパッケージ（%d plugin(s): %s）は正しくインストールされました。';
